pub struct SerializableAnimation {Show 18 fields
pub per_frame_joint_poses_shape: (usize, usize, usize),
pub per_frame_joint_poses_data: Vec<f32>,
pub per_frame_root_trans_shape: (usize, usize),
pub per_frame_root_trans_data: Vec<f32>,
pub per_frame_expression_coeffs_shape: Option<(usize, usize)>,
pub per_frame_expression_coeffs_data: Option<Vec<f32>>,
pub start_offset: usize,
pub anim_current_time_nanos: u64,
pub anim_reversed: bool,
pub nr_repetitions: u32,
pub paused: bool,
pub temporary_pause: bool,
pub fps: f32,
pub wrap_behaviour: u8,
pub angle_type: u8,
pub up_axis: u8,
pub smpl_type: u8,
pub face_type: u8,
}Expand description
Serializable version of Animation component
Fields
per_frame_joint_poses_shape: (usize, usize, usize)per_frame_joint_poses_data: Vec<f32>per_frame_root_trans_shape: (usize, usize)per_frame_root_trans_data: Vec<f32>per_frame_expression_coeffs_shape: Option<(usize, usize)>per_frame_expression_coeffs_data: Option<Vec<f32>>start_offset: usizeanim_current_time_nanos: u64anim_reversed: boolnr_repetitions: u32paused: booltemporary_pause: boolfps: f32wrap_behaviour: u8angle_type: u8up_axis: u8smpl_type: u8face_type: u8Trait Implementations
Sourceimpl Clone for SerializableAnimation
impl Clone for SerializableAnimation
Sourcefn clone(&self) -> SerializableAnimation
fn clone(&self) -> SerializableAnimation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableAnimation
impl Debug for SerializableAnimation
Sourceimpl<'de> Deserialize<'de> for SerializableAnimation
impl<'de> Deserialize<'de> for SerializableAnimation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl NetworkReceivable for SerializableAnimation
impl NetworkReceivable for SerializableAnimation
Sourcefn component_type_id() -> ComponentTypeId
fn component_type_id() -> ComponentTypeId
Get the component type identifier for this component type.
Sourceimpl NetworkSendable for SerializableAnimation
impl NetworkSendable for SerializableAnimation
Sourcefn serialize_to_bytes(&self) -> Result<Vec<u8>, EncodeError>
fn serialize_to_bytes(&self) -> Result<Vec<u8>, EncodeError>
Serialize this component to bytes for network transmission.
Sourcefn component_type_id(&self) -> ComponentTypeId
fn component_type_id(&self) -> ComponentTypeId
Get the component type identifier for this component type.
Sourceimpl Serialize for SerializableAnimation
impl Serialize for SerializableAnimation
Sourceimpl ToSerializable<SerializableAnimation> for Animation
impl ToSerializable<SerializableAnimation> for Animation
fn to_serializable(&self) -> SerializableAnimation