pub struct SerializableTransformSequence {
pub translations_shape: (usize, usize),
pub translations_data: Vec<f32>,
pub rotations_shape: (usize, usize),
pub rotations_data: Vec<f32>,
pub scales_shape: usize,
pub scales_data: Vec<f32>,
}Expand description
Serializable version of TransformSequence component
Fields
translations_shape: (usize, usize)translations_data: Vec<f32>rotations_shape: (usize, usize)rotations_data: Vec<f32>scales_shape: usizescales_data: Vec<f32>Trait Implementations
Sourceimpl Clone for SerializableTransformSequence
impl Clone for SerializableTransformSequence
Sourcefn clone(&self) -> SerializableTransformSequence
fn clone(&self) -> SerializableTransformSequence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SerializableTransformSequence
impl<'de> Deserialize<'de> for SerializableTransformSequence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl NetworkReceivable for SerializableTransformSequence
impl NetworkReceivable for SerializableTransformSequence
Sourcefn component_type_id() -> ComponentTypeId
fn component_type_id() -> ComponentTypeId
Get the component type identifier for this component type.
Sourceimpl NetworkSendable for SerializableTransformSequence
impl NetworkSendable for SerializableTransformSequence
Sourcefn serialize_to_bytes(&self) -> Result<Vec<u8>, EncodeError>
fn serialize_to_bytes(&self) -> Result<Vec<u8>, EncodeError>
Serialize this component to bytes for network transmission.
Sourcefn component_type_id(&self) -> ComponentTypeId
fn component_type_id(&self) -> ComponentTypeId
Get the component type identifier for this component type.